#define MOZ_SOURCE_STAMP 20f775af7b0683cddee6b8b51c7da42cf7974cf5
#define MOZ_SOURCE_REPO https://hg.mozilla.org/releases/mozilla-esr52
#define MOZ_SOURCE_URL https://hg.mozilla.org/releases/mozilla-esr52/rev/20f775af7b0683cddee6b8b51c7da42cf7974cf5
